@@ -145,8 +145,8 @@ class Code:
         repo = warez.Repo(bare_repo, init=True, bare=True)
         repo.update_server_info()
         repo.config("http.receivepack", "true")
-        # subprocess.run(["sudo", "chgrp", "www-data", bare_repo, "-R"])
-        # subprocess.run(["sudo", "chmod", "775", bare_repo, "-R"])
+        subprocess.run(["chgrp", "www-data", bare_repo, "-R"])
+        subprocess.run(["chmod", "g+w", bare_repo, "-R"])
         warez.clone_repo(bare_repo, working_repo)  # TODO shallow?
         return web.Created(app.view.project_created(project), f"/{project}")
 
